/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.adapters.input;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Container for ICY information received from Shoutcast stations.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 */
public class ICYInfo {

	public String notice1 = ""; // notices
	public String notice2 = "";
	public String notice3 = "";
	public String name = "P2P Streaming by dcg.ethz.ch"; // station name
	public String genre = "";
	public String url = ""; // station url
	public String contentType = "audio/mpeg";
	public int pub = 1; // public or private
	public int br = 128; // bit rate


	/**
	 * Sends ICY information to the specified output stream. Sending 'ICY 200
	 * OK' is enough to get winamp started.
	 * 
	 * @param out
	 *            the <code>OutputStream</code> to which to send the ICY
	 *            information
	 * @return true if the ICY information was sent successfully
	 */
	public boolean sendIcy( OutputStream out ){

		byte[] crlf = new byte[] { 13, 10 };
		try{
			out.write( new String( "ICY 200 OK" ).getBytes() );
			out.write( crlf );
			out.write( new String( "icy-notice1:" + notice1 ).getBytes() );
			out.write( crlf );
			if( notice2 != "" ){
				out.write( new String( "icy-notice2:" + notice2 ).getBytes() );
				out.write( crlf );
			}
			if( notice3 != "" ){
				out.write( new String( "icy-notice3:" + notice3 ).getBytes() );
				out.write( crlf );
			}
			out.write( new String( "icy-name:" + name ).getBytes() );
			out.write( crlf );
			out.write( new String( "icy-genre:" + genre ).getBytes() );
			out.write( crlf );
			out.write( new String( "icy-url:" + url ).getBytes() );
			out.write( crlf );
			out.write( new String( "content-type:" + contentType ).getBytes() );
			out.write( crlf );
			out.write( new String( "icy-pub:" + pub ).getBytes() );
			out.write( crlf );
			out.write( new String( "icy-br:" + br ).getBytes() );
			out.write( crlf );
			out.write( crlf );
		}catch( IOException e ){
			return false;
		}
		return true;
	}
}
