/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.adapters.input;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import ch.ethz.dcg.p2p.packets.Packetizer;

/**
 * Used to connect a media source to Swistry.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 * @see Adapter
 * @see ShoutCastAdapter
 * @see VlcHttpAdapter
 */
public abstract class InputAdapter implements Runnable, Adapter {

	protected final Log logger = LogFactory.getLog( this.getClass() );

	/**
	 * This is where the received bytes will be forwarded to.
	 */
	protected Packetizer target;


	/**
	 * Sets the <code>Packetizer</code> which splits the byte stream into
	 * discrete packets.
	 * 
	 * @param target
	 */
	public void setTarget( Packetizer target ){

		this.target = target;
	}


	/**
	 * Stops this input adapter; no more data will be received.
	 */
	public abstract void stop();


	/**
	 * Resets the flag that marks whether or not the content information has
	 * already been sent to the media sink.
	 */
	public abstract void resendContentInfo();
}
