/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.adapters.output;

import java.io.FileOutputStream;
import java.io.IOException;

import ch.ethz.dcg.p2p.peers.Node;

/**
 * <code>OutputAdapter</code> to forward the media stream to a file.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 * @see OutputAdapter
 * @see Mp3Adapter
 * @see VlcAdapter
 */
public class FileWriterAdapter extends OutputAdapter {

	private FileOutputStream out;


	/**
	 * Creates a new <code>FileWriterAdapter</code>.
	 * 
	 * @param out
	 *            the <code>OutputStream</code> to which to write the data.
	 * @param owner
	 *            the owner of this <code>OutputAdapter</code>
	 */
	public FileWriterAdapter( FileOutputStream out, Node owner ){

		this.out = out;
	}


	/**
	 * Writes the data into the file.
	 * 
	 * @param data
	 *            the data to write
	 * @param len
	 *            the length of the data
	 */
	public void dataAvailable( byte[] data, int len ){

		if( out != null ){
			try{
				out.write( data, 0, len );
			}catch( IOException e ){
				if( logger.isErrorEnabled() ){
					logger.error( "cannot write data to file (" + e.getMessage() + ")" );
				}
			}
		}
	}


	@Override
	public void resendContentInfo(){

		return;
	}

}
