/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.adapters.output;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import ch.ethz.dcg.p2p.adapters.input.Adapter;
import ch.ethz.dcg.p2p.utilities.DePacketizerListener;
import ch.ethz.dcg.p2p.utilities.ServerSocketListener;

/**
 * Used to connect a media sink to Swistry.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 * @see Adapter
 * @see FileWriterAdapter
 * @see Mp3Adapter
 * @see VlcAdapter
 */
public abstract class OutputAdapter implements DePacketizerListener, Adapter {

	protected final Log logger = LogFactory.getLog( this.getClass() );

	/**
	 * Thread which listens for incoming connections from media players.
	 */
	ServerSocketListener socketListener;


	/**
	 * Forwards data to the media player.
	 * 
	 * @param data
	 *            the payload to forward
	 * @param len
	 *            the length of the data array
	 */
	public abstract void dataAvailable( byte[] data, int len );


	/**
	 * Closes this <code>OutputAdapter</code>.<br>
	 * The <code>ServerSocketListener</code> will be closed.
	 */
	public void close(){

		if( socketListener != null ){
			socketListener.close();
		}
	}


	/**
	 * Resets the flag that marks whether or not the content information has
	 * already been sent to the media sink.
	 */
	public abstract void resendContentInfo();

}
