/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.gui;

import aw.gui.chart.AbstractDataCollector;
import aw.gui.chart.ITrace2D;
import aw.gui.chart.TracePoint2D;
import ch.ethz.dcg.p2p.peers.Node;

/**
 * Extension of the <code>AbstractDataCollector</code> which is a thread
 * collecting inbound bandwidth statistics and forwards it to the chart in the
 * gui.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 * @see AbstractDataCollector
 * @linkplain http://jchart2d.sourceforge.net/
 */
public class DownloadDataCollector extends AbstractDataCollector {

	/**
	 * time keeping
	 */
	private long start = System.currentTimeMillis();
	private long lastUpdate = start;

	/**
	 * number of packets received
	 */
	private long lastPacketsReceived = 0;
	private long curPacketsReceived = 0;


	/**
	 * Creates a new DownloadDataCollector.
	 * 
	 * @param trace
	 *            the trace to add collected points to
	 * @param latency
	 *            the interval in ms for collecting points
	 */
	public DownloadDataCollector( ITrace2D trace, long latency ){

		super( trace, latency );
	}


	/**
	 * Collects a new data point which is how many kbps were downloaded in the
	 * last interval.
	 * 
	 * @return the new data point for the chart
	 */
	public TracePoint2D collectData(){

		long now = System.currentTimeMillis();
		long interval = now - lastUpdate;
		curPacketsReceived = Node.statistic.getTotalPacketsReceived();

		double download = ( ( curPacketsReceived - lastPacketsReceived ) * Node.statistic.getPacketSize() * 8 ) / Math.max( interval, 1 );

		lastUpdate = now;
		lastPacketsReceived = curPacketsReceived;

		return new TracePoint2D( (double)( System.currentTimeMillis() - start ) / 1000, download );
	}
}
