/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.handlers;

import java.io.DataOutputStream;
import java.io.IOException;
import java.net.Socket;

import ch.ethz.dcg.p2p.exceptions.NodeNotConfiguredException;
import ch.ethz.dcg.p2p.peers.Neighbour;
import ch.ethz.dcg.p2p.peers.Node;
import ch.ethz.dcg.p2p.tasks.Task;
import ch.ethz.dcg.p2p.utilities.ProtocolConstants;
import ch.ethz.dcg.p2p.utilities.Utilities;

/**
 * Handler for incoming DIRECTREPORTNEIGHBOURS messages.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 */
public class DirectReportNeighboursHandler extends Task {

	/**
	 * Creates a new <code>HelloHandler</code>.
	 * 
	 * @param socket
	 *            the TCP connection connection to the sender
	 * @param source
	 *            the owner of this task
	 */
	public DirectReportNeighboursHandler( Socket socket, Node source ){

		this.socket = socket;
		this.source = source;
	}


	/**
	 * Sends a list of all the <code>Neighbour</code>s to the host that is
	 * asking for it.
	 */
	public void run(){

		if( logger.isDebugEnabled() ){
			logger.debug( "DirectReportNeighboursHandler started" );
		}

		try{
			DataOutputStream out = new DataOutputStream( socket.getOutputStream() );
			out.write( ProtocolConstants.DIRECTNEIGHBOURS );
			out.writeInt( source.getNNeighbours() );
			for( Neighbour curN : source.getNeighboursCopy() ){
				Utilities.writeIP( curN.getIp(), out );
				out.writeInt( curN.getPort() );
			}
			out.flush();
			if( logger.isInfoEnabled() ){
				logger.info( "DIRECTNEIGHBOURS message sent to " + socket.getInetAddress().getHostAddress() );
			}
		}catch( IOException e ){
			if( logger.isErrorEnabled() ){
				logger.error( "cannot send DIRECTNEIGHBOURS message to " + socket.getInetAddress().getHostAddress() );
			}
		}catch( NodeNotConfiguredException e ){
			if( logger.isErrorEnabled() ){
				logger.error( e.getMessage() );
			}
		}
	}
}
