/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.main;

import java.net.InetAddress;
import java.net.UnknownHostException;

import ch.ethz.dcg.p2p.utilities.Diagnostics;

/**
 * Test the diagnostics utility from the console.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 */
public class DiagnosticsTester {

	Diagnostics d = new Diagnostics( 3, 1000 );


	public static void main( String[] args ){

		DiagnosticsTester tester = new DiagnosticsTester();
		int i = 1;

		if( args.length < 3 ){
			printUsage();
			return;
		}else if( args[0].equalsIgnoreCase( "diameter" ) ){
			try{
				int diameter = tester.d.calcDiameter( InetAddress.getByName( args[i++] ), new Integer( args[i++] ).intValue() );
				System.out.println( "Diameter: " + diameter );
			}catch( UnknownHostException e ){
				System.out.println( "Unknown Host: " + args[0] );
			}
			return;
		}

		if( args.length < 6 ){
			printUsage();
			return;
		}
		try{
			if( args[0].equalsIgnoreCase( "conn" ) ){
				tester.d.connected( InetAddress.getByName( args[i++] ), InetAddress.getByName( args[i++] ), new Integer( args[i++] ).intValue(), new Integer( args[i++] ).intValue(), new Integer( args[i++] ).intValue() );
			}else if( args[0].equalsIgnoreCase( "neigh" ) ){
				tester.d.reportNeighbours( InetAddress.getByName( args[i++] ), InetAddress.getByName( args[i++] ), new Integer( args[i++] ).intValue(), new Integer( args[i++] ).intValue(), new Integer( args[i++] ).intValue() );
				if( tester.d.checkNeighbourhoodConsistency() ){
					System.out.println( "Neighbourhood consistent" );
				}else{
					System.out.println( "Neighbourhood not consistent" );
				}
			}else{
				printUsage();
			}
		}catch( UnknownHostException e ){
			System.out.println( "Unknown Host: " + args[0] );
		}

	}


	public static void printUsage(){

		System.out.println( "Arguments: <\"conn\"|\"neigh\"> <diagIp> <firstPeerIP> <firstPeerPort> <floodID> <nPeersInNetwork>" );
		System.out.println( "or for diameter: <\"diameter\"> <firstPeerIP> <firstPeerPort>" );
	}

}
