/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.peers;

import java.net.InetAddress;

import ch.ethz.dcg.p2p.utilities.ProtocolConstants;

/**
 * Adds additional information to the <code>Neighbour</code> which the
 * <code>NetworkEntryPoint</code> needs. This type is used to represent
 * neighbours of the <code>NetworkEntryPoint</code>.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 */
public class NEPNeighbour extends Neighbour {

	private int speed = 0;
	private int level = -1;
	private byte nodeType = ProtocolConstants.PEER;


	/**
	 * Creates a new <code>NEPNeighbour</code>.
	 * 
	 * @param ip
	 * @param port
	 * @param nodeType
	 * @param speed
	 */
	public NEPNeighbour( InetAddress ip, int port, byte nodeType, int speed ){

		super( ip, port );
		this.nodeType = nodeType;
		this.speed = speed;
		if( nodeType == ProtocolConstants.SOURCE ){
			level = speed;
			setSourceSpeed();
		}
	}


	/**
	 * Get the speed of this node which is the outbound speed he has declared
	 * upon joining.
	 * 
	 * @return the speed of this node
	 */
	public int getSpeed(){

		return speed;
	}


	/**
	 * Get the level to which this node belongs.
	 * 
	 * @return the level to which this node belongs
	 */
	public int getLevel(){

		return level;
	}


	/**
	 * Set the speed of this <code>NEPNeighbour</code> to be
	 * <code>Integer.MAX_VALUE</code>. If this <code>NEPNeighbour</code>
	 * does not represent a Source; it will have no effect.
	 * 
	 * @return the speed of this NEPNeighbour
	 */
	private int setSourceSpeed(){

		if( nodeType == ProtocolConstants.SOURCE ){
			speed = Integer.MAX_VALUE;
		}
		return speed;
	}


	/**
	 * Get the typ of node this <code>NEPNeighbour</code> represents.
	 * 
	 * @return the type of this <code>NEPNeighbour</code>
	 */
	public byte getNodeType(){

		return nodeType;
	}
}
