/**
 * Swistry is a 3rd generation Peer-to-Peer streaming system 
 * that supports live audio and video broadcasting over the Internet.
 * 
 * Copyright (C) 2006  Philip Frey
 * 
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 * 
 * Contact the author: philip.frey@alumni.ethz.ch
 */

package ch.ethz.dcg.p2p.utilities;

import java.io.IOException;
import java.io.OutputStream;
import java.net.ServerSocket;
import java.net.Socket;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import ch.ethz.dcg.p2p.adapters.input.Adapter;
import ch.ethz.dcg.p2p.peers.Node;

/**
 * Helper class that listens for incoming TCP connections.
 * 
 * @author Philip Frey (philip.frey@alumni.ethz.ch)
 */
public class ServerSocketListener extends Thread {

	protected final Log logger = LogFactory.getLog( this.getClass() );

	private ServerSocket localServerSocket;
	private Socket localSocket;
	private int listeningPort;
	public OutputStream out;
	private Node source;
	private Adapter adapter;


	/**
	 * Creates a new <code>ServerSocketListener</code>.
	 * 
	 * @param listeningPort
	 *            the port to listen on
	 * @param source
	 *            the owner of this listener
	 * @param adapter
	 *            a possibly available output adapter in case this listener is
	 *            used for communication with a media player
	 */
	public ServerSocketListener( int listeningPort, Node source, Adapter adapter ){

		this.listeningPort = listeningPort;
		this.source = source;
		this.adapter = adapter;
		setName( "ServerSocketListener" );
	}


	/**
	 * Starts this listener.
	 */
	public void run(){

		try{
			localServerSocket = new ServerSocket( listeningPort );
			while( true ){
				localSocket = localServerSocket.accept();
				// only one connection allowed
				if( out == null ){
					out = localSocket.getOutputStream();
					if( logger.isDebugEnabled() ){
						logger.debug( "local socket open at port(" + localSocket.getPort() + ")" );
					}
					source.write2gui( "media player connected to media-socket" );
				}else{
					out = localSocket.getOutputStream();
					adapter.resendContentInfo();
					source.write2gui( "reconnect to media player" );
				}
			}
		}catch( IOException e ){
			if( logger.isFatalEnabled() ){
				logger.fatal( "problems with the local server socket: " + e.getMessage() );
			}
		}
	}


	/**
	 * Closes this listener.
	 */
	public void close(){

		try{
			localServerSocket.close();
		}catch( Exception e ){
		}
	}
}
